California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 76 - SCHOOL FUNDING. STATE SPENDING. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1279937 | REFORM CALIFORNIA, YES ON 74, 75 & 76, WITH MAJOR FUNDING BY SHELDON G. ADELSON | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1277766 | NO ON 76, EDUCATORS, FIREFIGHTERS, SCHOOL EMPLOYEES, HEALTH CARE GIVERS AND LABOR ORGANIZATIONS OPPOSED TO SCHOOL CUTS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1277456 | COMMITTEE TO PROTECT CALIFORNIA'S FUTURE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280140 | CALIFORNIANS AGAINST ARNOLD'S SPECIAL INTEREST ELECTION - NO ON 73, 74, 75, 76, 77 AND 78 AND YES ON 79 AND 80, SPONSORED BY WORKING ASSETS AND BALLOT INITIATIVE STRATEGY CENTER | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1279283 | ACTIONIMPACT.ORG, A COALITION OF BUSINESSES AND TAXPAYERS AGAINST PROP 76 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1278872 | NO SPECIAL ELECTION - 41ST AD FIGHTING PROPOSITIONS 73, 74, 75, 76 AND 78 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1281170 | NO ON 74, 75: FINANCED BY COUNCIL PRESIDENT ALEX PADILLA COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280977 | ASIAN PACIFIC AMERICANS FOR AN INFORMED CALIFORNIA, SPONSORED BY THE ASIAN LAW CAUCUS, A COMMITTEE AGAINST PROPOSITIONS 73, 74, 75, 76, AND 77 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280882 | HAYASHI'S NO ON 74,75 76 COMMITTEE, MARY | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1261406 | SCHWARZENEGGER'S CALIFORNIA RECOVERY TEAM, GOVERNOR | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1273022 | CITIZENS TO SAVE CALIFORNIA, A COALITION OF BUSINESS & TAXPAYER ORGANIZATIONS TO REFORM CALIFORNIA GOVERNMENT AND POLITICS, YES ON PROPOSITIONS 74 & 76 | SUPPORT